################################################################################
# R Code related to                                                            #
# Drought effects on hay and feed grain prices                                 #
# Sergei Schaub and Robert Finger                                              #    
# -----------------------------------------------------------------------------#
# Main r script                                                                #
#  2019, ETH Zurich                                                           #
# developed by Sergei Schaub                                                   #  
################################################################################


# table of contents:
# 0. general settings
# 1. create folders and specify directories 
# 2. call r scripts


# !!! Important remarks !!!:
# a) Before running the R code you need to specify your main working directory, i.e. 'cd_main' (you find it in section 0)
#    and manually create in the main directory a file 'r_code' in which you save all the provide r scripts
# b) After doing a) run the code until the end of section 1. 
# c) Save the online provided data and downloaded data* in the folder 'input_data' except 'spei_data_SG_DE.csv' 
## c.1) If you only want to run the estimation put the input file 'spei_data_SG_DE.csv' in the folder 'input_data/weather_data/processed'. 
##      It is recommended to only run the estimation. As itself already takes several hours and the data generation even days.
## c.2) If you want to run all code (including creation of weather input data, which takes several days depending on the computer)
##      please do not put file 'spei_data_SG_DE.csv' in the folder 'input_data/weather_data/processed'
## c.3) specify in section 2 if you want to do c.1 or c.2
# d) run section 2

# * Note that you need to download the shape files containing administrative area and land cover
#    - administrative area: https://gdz.bkg.bund.de/index.php/default/digitale-geodaten/verwaltungsgebiete/verwaltungsgebiete-1-250-000-ebenen-stand-01-01-vg250-ebenen-01-01.html
#    - land cover: https://gdz.bkg.bund.de/index.php/default/open-data/corine-land-cover-10-ha-clc10.html
# located the entire unzipped files in the folder 'input_data'

################################################################################
#------------------------------- 0. general settings
################################################################################

# install packages
# install.packages(c("curl","esmisc","R.utils","raster","rgdal","sp","SPEI","stringr","tidyverse","tseries","lmtest","vars","ggpubr","imputeTS"))

# load packages
require(curl)
require(esmisc)
require(R.utils)
require(raster)
require(rgdal)
require(sp)
require(SPEI)
require(stringr)
require(tidyverse)
require(tseries)
require(lmtest)
require(vars)
require(ggpubr)



################################################################################
#------------------------------- 1. create folders and specify directories 
################################################################################

# define main working directory 
cd_main <- "H:/feed_prices"        #### !!! Needs to be specified !!!
setwd(cd_main) # set directory


# create additional folders and working directories 
## r code
cd_code <- paste0(cd_main,"/r_code")

## input data
dir.create("input_data")
cd_input_data <- "H:/feed_prices/input_data"


### weather data
setwd(cd_input_data) # set directory
dir.create("weather_data")
cd_weather_data <- "H:/feed_prices/input_data/weather_data"

#### evapotranspiration
setwd(cd_weather_data) # set directory
dir.create("evapo_p")
cd_evapo_p <- "H:/feed_prices/input_data/weather_data/evapo_p"

#### precipitation
dir.create("precipitation")
cd_precipitation <- "H:/feed_prices/input_data/weather_data/precipitation"

#### processed
dir.create("processed")
cd_processed <- "H:/feed_prices/input_data/weather_data/processed"

## results
setwd(cd_main) # set directory
dir.create("results")
cd_results <- "H:/feed_prices/results"

### figures 
setwd(cd_results) # set directory
dir.create("figures")
cd_figures <- "H:/feed_prices/results/figures"

### tables 
dir.create("tables")
cd_tables <- "H:/feed_prices/results/tables"


################################################################################
#------------------------------- 2. call r scripts
################################################################################

# onlyEstimation=1 run only estimation (c.1), onlyEstimation=0 generate weather data and run estimation (c.2) 
onlyEstimation = 0 #### !!! Needs to be specified !!! 

setwd(cd_code) # set directory

# run r scripts
if(onlyEstimation==1){source("r_estimation_script_feed_price_paper.R")} else if(onlyEstimation==0){
  source("r_estimation_script_feed_price_paper.R")
  source("('r_weather_script_feed_price_paper.R")}  
